@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v1.0.5
 dpt_vfs/abstract.py
 """
 
@@ -51,7 +51,7 @@ Link type
 
     # pylint: disable=invalid-name
 
-    __slots__ = [ "__weakref__" ] + FileLikeCopyMixin._mixin_slots_ + SupportsMixin._mixin_slots_
+    __slots__ = ( "__weakref__", ) + FileLikeCopyMixin._mixin_slots_ + SupportsMixin._mixin_slots_
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
