@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v1.0.5
 dpt_vfs/abstract_watcher.py
 """
 
@@ -47,7 +47,7 @@ Deleted event
 Created event
     """
 
-    __slots__ = [ "__weakref__" ]
+    __slots__ = ( "__weakref__", )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
