@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v1.0.5
 dpt_vfs/dpt_vfs/file/object.py
 """
 
@@ -65,7 +65,7 @@ Provides the VFS implementation for 'file' objects.
 File IO methods implemented by an wrapped resource.
     """
 
-    __slots__ = [ "dir_path_name", "file_path_name", "object_readonly" ] + FileLikeWrapperMixin._mixin_slots_
+    __slots__ = ( "dir_path_name", "file_path_name", "object_readonly" ) + FileLikeWrapperMixin._mixin_slots_
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
