@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v1.0.5
 dpt_vfs/dpt_vfs/file/watcher_mtime.py
 """
 
@@ -42,7 +42,7 @@ class WatcherMtime(object):
              Mozilla Public License, v. 2.0
     """
 
-    __slots__ = [ ]
+    __slots__ = ( )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
