@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v1.0.5
 dpt_vfs/dpt_vfs/file/watcher_pyinotify.py
 """
 
@@ -46,13 +46,13 @@ class WatcherPyinotify(pyinotify.WatchManager):
     """
 
     # pylint: disable=bad-option-value,slots-on-old-class
-    __slots__ = [ "__weakref__",
+    __slots__ = ( "__weakref__",
                   "_lock",
                   "_pyinotify_instance",
                   "watched_callbacks",
                   "watched_path_files",
                   "watched_paths"
-                ]
+                )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
