@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v1.0.5
 dpt_vfs/dpt_vfs/file/watcher_pyinotify_callback.py
 """
 
@@ -47,7 +47,7 @@ Processes pyinotify events and calls defined callbacks.
     # pylint: disable=invalid-name
 
     # pylint: disable=bad-option-value,slots-on-old-class
-    __slots__ = [ "manager_weakref" ]
+    __slots__ = ( "manager_weakref", )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
