@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v1.0.5
 dpt_vfs/file_like_wrapper_mixin.py
 """
 
@@ -46,11 +46,11 @@ instance.
 File IO methods implemented by an wrapped resource.
     """
 
-    _mixin_slots_ = [ "_wrapped_resource" ]
+    _mixin_slots_ = ( "_wrapped_resource", )
     """
 Additional __slots__ used for inherited classes.
     """
-    __slots__ = [ ]
+    __slots__ = ( )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
